package Template::Refine;

our $VERSION = '0.02';

1;

__END__

=head1 NAME

Template::Refine - refine HTML

=head1 DETAILS

See L<Template::Refine::Fragment>, it's currently the main entry
point.

You can also read the L<Template::Refine::Cookbook>.

=head1 AUTHOR

Jonathan Rockway C<< <jrockway@cpan.org> >>

=head1 COPYRIGHT

    Copyright (c) 2008 Infinity Interactive. This program is free
    software; you can redistribute it and/or modify it under the same
    terms as Perl itself.

